@@ -6,7 +6,10 @@ mod internal;
     target_os = "linux",
     target_os = "macos",
     target_os = "freebsd",
-    target_os = "openbsd"
+    target_os = "netbsd",
+    target_os = "openbsd",
+    target_os = "android",
+    target_os = "illumos",
 ))]
 #[path = "linux.rs"]
 mod internal;
